@@ -58,7 +58,7 @@ DeviceManager::DeviceManager() : m_playingDevice(0)
     gst_bus_add_watch (bus, deviceMonitorWatch, m_monitor);
     gst_object_unref (bus);
 
-    GstCaps *caps = gst_caps_new_empty_simple ("image/jpeg");
+    GstCaps *caps = gst_caps_new_empty_simple ("video/x-raw");
     gst_device_monitor_add_filter (m_monitor, "Video/Source", caps);
     gst_caps_unref (caps);
 
@@ -71,15 +71,19 @@ DeviceManager::DeviceManager() : m_playingDevice(0)
     }
 
     /* Initialize camera structures */
-    while(devices) {
-        deviceAdded(GST_DEVICE(devices->data));
-        devices = devices->next;
+    for(; devices; devices = devices->next) {
+        auto device = new Device(GST_DEVICE(devices->data), this);
+        if (!device->isValid()) {
+            delete device;
+            continue;
+        }
+        m_deviceList.append(device);
     }
 
     g_list_free (devices);
 
     if (!m_deviceList.isEmpty()) {
-        setPlayingDeviceUdi(m_deviceList.first()->udi());
+        setPlayingDeviceUdi(m_deviceList.constFirst()->udi());
     }
 }
 
@@ -126,7 +130,8 @@ void DeviceManager::setPlayingDeviceUdi(const QString& udi)
         }
     }
 
-    m_playingDevice = 0;
+    qWarning() << "could not find device" << udi;
+    m_playingDevice = nullptr;
 }
 
 Device* DeviceManager::playingDevice()
@@ -174,15 +179,11 @@ QVariant DeviceManager::data(const QModelIndex& index, int role) const
 
 void DeviceManager::deviceAdded(GstDevice* device)
 {
-    auto st = gst_device_get_properties(device);
-
     const int s = m_deviceList.size();
     beginInsertRows({}, s, s);
-    m_deviceList.append(new Device(st, this));
+    m_deviceList.append(new Device(device, this));
     endInsertRows();
 
-    gst_structure_free(st);
-
     if (!m_playingDevice) {
         setPlayingDeviceUdi(m_deviceList.first()->udi());
     }
